@@ -16,7 +16,7 @@ if __name__ == "__main__":
 import sumolib.utils
 import sumolib.JSON
 
-__version__="4.2" #VERSION#
+__version__="4.3" #VERSION#
 
 assert __version__==sumolib.utils.__version__
 assert __version__==sumolib.JSON.__version__
@@ -159,6 +159,15 @@ class Spec():
             return k1<=k2
         raise ValueError("unknown flag: '%s'" % repr(flag))
 
+    def equal(self, version):
+        """Test if a version is equal to a spec.
+
+        Note: this returns always False when self.versionflag!="eq".
+        """
+        if self.versionflag!="eq":
+            return False
+        return self.versionname == version
+
     def test(self, version):
         """Test if a version matches the spec.
 
@@ -194,7 +203,7 @@ class Specs():
     """A class representing a list of Spec objects."""
     # pylint: disable=R0903
     #         Too few public methods
-    def __init__(self, speclist):
+    def __init__(self, speclist= None):
         """note: this DOES NOT a deep copy of the list.
 
         Here is an example:
@@ -209,15 +218,25 @@ class Specs():
         Spec('A','R2','eq')
         Spec('B','R2','eq')
         """
-        self.specs= speclist
+        if speclist is None:
+            self.specs= []
+        else:
+            self.specs= speclist
     def __repr__(self):
         """return repr string."""
         return "%s(%s)" % (self.__class__.__name__,
                            ",".join([repr(s) for s in self.specs]))
+    def sorted(self):
+        """return a sorted "specs" object."""
+        new= sorted(self.specs, key= lambda s: s.modulename)
+        return self.__class__(new)
     def __iter__(self):
         """the default iterator."""
         for m in self.specs:
             yield m
+    def add(self, spec):
+        """add a new module spec."""
+        self.specs.append(spec)
     @staticmethod
     def scan_special(st):
         """scan special in-line commands."""
@@ -374,6 +393,12 @@ class Specs():
         for spec in self:
             d[spec.modulename]= spec.versionname
         return d
+    def module_set(self):
+        """return a set containing all module names."""
+        s= set()
+        for spec in self:
+            s.add(spec.modulename)
+        return s
 
 def _test():
     """perform internal tests."""
